Programmes et des modules Python — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »

# Programmes et des modules Python

Contenu:

`Hourly` | Obtient les données météorologiques, les traite, prépare les fichiers de graphes & textes et les téléverse sur un site web.
`LiveLog` | Obtient les données météo, les stocke et les traite.
`Reprocess` | Regenerate hourly and daily summary data
`TwitterAuth` | Autorise pywws à publier sur votre compte Twitter
`SetWeatherStation` | Set some weather station parameters
`TestWeatherStation` | Teste la connexion à la station météo.
`RunModule` | Run a pywws module.
`USBQualityTest` | Teste la qualité de la connexion USB avec votre station météo
`EWtoPy` | Convert EasyWeather.dat data to pywws format
`pywws.Tasks` | Routines pour effectuer des tâches courantes telles que tracer les gaphes ou téléverser des fichiers.
`pywws.LogData` | Enregistrer l’historique de la station météo dans un fichier
`pywws.Process` | Générer les relevés horaire, quotidien et mensuels à partir des données brutes de la station météo
`pywws.calib` | Calibre les données brutes de la station météo
`pywws.Plot` | Plot graphs of weather data according to an XML recipe
`pywws.WindRose` | Plot a “wind rose”
`pywws.Template` | Create text data file based on a template
`pywws.Forecast` | Predict future weather using recent data
`pywws.ZambrettiCore` |
`pywws.Upload` | Upload files to a web server by ftp or copy them to a local directory
`pywws.ToTwitter` | Poste un message sur Twitter
`pywws.toservice` | Poste une mise à jour météo pour des services tels que Weather Underground
`pywws.YoWindow` | Generate YoWindow XML file
`pywws.WeatherStation` | Obtient les données des stations météorologiques WH1080/WH3080 et compatibles.
`pywws.device_cython_hidapi` | Low level USB interface to weather station, using cython-hidapi.
`pywws.device_pyusb` | Interface USB de bas niveau de la station météo, utilisant PyUSB.
`pywws.DataStore` | DataStore.py - enregistre les lectures dans des fichiers facilement accessibles
`pywws.TimeZone` | Fourni un couple d’objets datetime.tzinfo () représentant le temps local
`pywws.Localisation` | Localisation.py - fournit des traductions de phrases en langue locale
`pywws.calib` | Calibre les données brutes de la station météo
`pywws.conversions` | conversions.py est un ensemble de fonctions pour convertir les unités pywws natives
`pywws.Logger` | Code commun pour l’enregistrement d’informations et d’erreurs.

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »